from django.apps import AppConfig


class LocalAppConfig(AppConfig):
    name = 'local_app'
    default = False
